"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const parse_result_1 = require("../parse_result");
class Neo4jBoltSession {
    constructor(session, options) {
        this.session = session;
        this.options = options;
    }
    execute(query, options = {}) {
        return new Promise((resolve, reject) => {
            const parsedRecords = [];
            this.session.run(query).subscribe({
                onCompleted: () => {
                    if (options.singularOutput) {
                        resolve(parsedRecords[0]);
                    }
                    else {
                        resolve(parsedRecords);
                    }
                    this.session.close();
                },
                onError: (error) => {
                    reject(error);
                    this.session.close();
                },
                onNext: (record) => {
                    const parsedRecord = parse_result_1.parseNeo4jResult(record, this.options.stringFormatter);
                    if (options.singularOutput && parsedRecords.length > 1) {
                        reject(new Error(`multiple records returned in signular mode`));
                        return this.session.close();
                    }
                    parsedRecords.push(parsedRecord);
                },
            });
        });
        // promise approach to get all results at once
        // const result = await this.session.run(query);
        // this.session.close();
        // return this.parseRecords(result.records, {
        //     singularOutput: options.singularOutput,
        //     stringFormatter: this.options.stringFormatter,
        // });
    }
}
exports.Neo4jBoltSession = Neo4jBoltSession;
//# sourceMappingURL=bolt_session.js.map