"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const parse_result_1 = require("../parse_result");
const bolt_abstract_1 = require("./bolt_abstract");
class Neo4jBoltTransactionalSession extends bolt_abstract_1.AbstractBoltSession {
    constructor(session, options) {
        super();
        this.session = session;
        this.options = options;
        this.transaction = session.beginTransaction();
    }
    async execute(query, options = {}) {
        return new Promise((resolve, reject) => {
            const parsedRecords = [];
            this.session.run(query).subscribe({
                onCompleted: () => {
                    if (options.singularOutput) {
                        resolve(parsedRecords[0]);
                    }
                    else {
                        resolve(parsedRecords);
                    }
                    this.session.close();
                },
                onError: (error) => {
                    reject(error);
                    this.session.close();
                },
                onNext: (record) => {
                    const parsedRecord = parse_result_1.parseNeo4jResult(record, this.options.stringFormatter);
                    if (options.singularOutput && parsedRecords.length > 1) {
                        reject(new Error(`multiple records returned in signular mode`));
                        return this.session.close();
                    }
                    parsedRecords.push(parsedRecord);
                },
            });
        });
    }
    async commit() {
        const result = await this.transaction.commit();
        this.session.close();
        return this.parseRecords(result.records, {
            stringFormatter: this.options.stringFormatter,
        });
    }
    async rollback() {
        const result = await this.transaction.rollback();
        this.session.close();
        return this.parseRecords(result.records, {
            stringFormatter: this.options.stringFormatter,
        });
    }
    isOpen() {
        return this.transaction.isOpen();
    }
}
exports.Neo4jBoltTransactionalSession = Neo4jBoltTransactionalSession;
//# sourceMappingURL=bolt_transactional_session.js.map