"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const neo4j_driver_1 = require("neo4j-driver");
const bolt_session_1 = require("./bolt/bolt_session");
const bolt_transactional_session_1 = require("./bolt/bolt_transactional_session");
const options_interface_1 = require("./types/options.interface");
class Neo4jClient {
    constructor(options) {
        this.options = getCompleteClientOptions(options);
        const authToken = getAuthenticationToken(this.options.authentication);
        this.client = neo4j_driver_1.v1.driver(`${options.protocol}://${options.host}:${options.port}`, authToken, {
            connectionTimeout: options.connectionTimeout,
            maxConnectionPoolSize: options.connectionLimit,
        });
        // TODO: add implementation for other protocols
    }
    getSession() {
        const session = this.client.session();
        return new bolt_session_1.Neo4jBoltSession(session, {
            stringFormatter: this.options.stringFormatter,
        });
    }
    getTransactionalSession() {
        const session = this.client.session();
        return new bolt_transactional_session_1.Neo4jBoltTransactionalSession(session, {
            stringFormatter: this.options.stringFormatter,
        });
    }
}
exports.Neo4jClient = Neo4jClient;
const DEFAULT_BOLT_OPTIONS = {
    authentication: {},
    connectionLimit: 8,
    connectionTimeout: 60 * 1000,
    logLevel: options_interface_1.LogLevel.ERROR,
    logTimed: true,
    port: 7687,
    protocol: options_interface_1.Neo4jConnectionProtocol.BOLT,
    stringFormatter: (value) => value,
};
function getCompleteClientOptions(partialOptions) {
    if (!partialOptions.protocol || partialOptions.protocol === options_interface_1.Neo4jConnectionProtocol.BOLT) {
        return Object.assign({}, DEFAULT_BOLT_OPTIONS, partialOptions);
    }
    else {
        throw new Error("HTTP session not implemented yet");
    }
}
function getAuthenticationToken(authentication) {
    if (authentication.username && authentication.password) {
        return neo4j_driver_1.v1.auth.basic(authentication.username, authentication.password);
    }
    else if (authentication.ticket) {
        const credentialsString = Buffer.from(authentication.ticket, "base64").toString();
        const [username, password] = credentialsString.split(":");
        return neo4j_driver_1.v1.auth.basic(username, password);
    }
    return undefined;
}
//# sourceMappingURL=client.js.map